@@ -51,3 +51,16 @@ CATEGORY_IMAGE = "image"
 CATEGORY_DYNAMICIMG = "dynamic_img"
 CATEGORY_SUBTITLE = "subtitle"
 CATEGORY_FONT = "font"
+
+SMS_CHANNEL_TYPE_CN_OTP = "CN_OTP"
+SMS_CHANNEL_TYPE_CN_NTC = "CN_NTC"
+SMS_CHANNEL_TYPE_CN_MKT = "CN_MKT"
+SMS_CHANNEL_TYPE_I18N_OTP = "I18N_OTP"
+SMS_CHANNEL_TYPE_I18N_MKT = "I18N_MKT"
+
+ENABLE_STATUS_NOT_ENABLE = "0"
+ENABLE_STATUS_ENABLE = "1"
+
+AREA_CN = "cn"
+AREA_OVERSEAS = "overseas"
+AREA_ALL = "all"
