@@ -72,6 +72,9 @@ class VisualService(Service):
             "ImageSearchImageAdd": ApiInfo("POST", "/", {"Action": "ImageSearchImageAdd", "Version": "2020-08-26"}, {}, {}),
             "ImageSearchImageDelete": ApiInfo("POST", "/", {"Action": "ImageSearchImageDelete", "Version": "2020-08-26"}, {}, {}),
             "ImageSearchImageSearch": ApiInfo("POST", "/", {"Action": "ImageSearchImageSearch", "Version": "2020-08-26"}, {}, {}),
+            "ProductSearchAddImage": ApiInfo("POST", "/", {"Action": "ProductSearchAddImage", "Version": "2022-06-16"}, {}, {}),
+            "ProductSearchDeleteImage": ApiInfo("POST", "/", {"Action": "ProductSearchDeleteImage", "Version": "2022-06-16"}, {}, {}),
+            "ProductSearchSearchImage": ApiInfo("POST", "/", {"Action": "ProductSearchSearchImage", "Version": "2022-06-16"}, {}, {}),
             "ClueLicense": ApiInfo("POST", "/", {"Action": "OcrClueLicense", "Version": "2020-08-26"}, {}, {}),
             "DrivingLicense": ApiInfo("POST", "/", {"Action": "DrivingLicense", "Version": "2020-08-26"}, {}, {}),
             "VehicleLicense": ApiInfo("POST", "/", {"Action": "VehicleLicense", "Version": "2020-08-26"}, {}, {}),
@@ -99,6 +102,8 @@ class VisualService(Service):
             "VideoCoverSelection": ApiInfo("POST", "/", {"Action": "VideoCoverSelection", "Version": "2020-08-26"}, {}, {}),
             "VideoHighlightExtractionSubmitTask": ApiInfo("POST", "/", {"Action": "VideoHighlightExtractionSubmitTask", "Version": "2020-08-26"}, {}, {}),
             "VideoHighlightExtractionQueryTask": ApiInfo("GET", "/", {"Action": "VideoHighlightExtractionQueryTask", "Version": "2020-08-26"}, {}, {}),
+            "CertToken": ApiInfo("POST", "/", {"Action": "CertToken", "Version": "2022-08-31"}, {}, {}),
+            "CertVerifyQuery": ApiInfo("POST", "/", {"Action": "CertVerifyQuery", "Version": "2022-08-31"}, {}, {}),
         }
         return api_info
 
@@ -129,6 +134,21 @@ class VisualService(Service):
             except:
                 raise Exception(str(e))
 
+    def common_json_handler(self, api, form):
+        params = dict()
+        try:
+            res = self.json(api, params, json.dumps(form))
+            res_json = json.loads(res)
+
+            return res_json
+        except Exception as e:
+            res = str(e)
+            try:
+                res_json = json.loads(res)
+                return res_json
+            except:
+                raise Exception(str(e))
+
     def jpcartoon_cut(self, form):
         try:
             res_json = self.common_handler("JPCartoonCut", form)
@@ -409,14 +429,35 @@ class VisualService(Service):
             return res_json
         except Exception as e:
             raise Exception(str(e))
-    
+
     def image_search_image_search(self, form):
         try:
             res_json = self.common_handler("ImageSearchImageSearch", form)
             return res_json
         except Exception as e:
             raise Exception(str(e))
-    
+
+    def product_search_add_image(self, params):
+        try:
+            res_json = self.json("ProductSearchAddImage", [], json.dumps(params))
+            return res_json
+        except Exception as e:
+            raise Exception(str(e))
+
+    def product_search_delete_image(self, params):
+        try:
+            res_json = self.json("ProductSearchDeleteImage", [], json.dumps(params))
+            return res_json
+        except Exception as e:
+            raise Exception(str(e))
+
+    def product_search_search_image(self, params):
+        try:
+            res_json = self.json("ProductSearchSearchImage", [], json.dumps(params))
+            return res_json
+        except Exception as e:
+            raise Exception(str(e))
+
     def clue_license(self, form):
         try:
             res_json = self.common_handler("ClueLicense", form)
@@ -437,7 +478,7 @@ class VisualService(Service):
             return res_json
         except Exception as e:
             raise Exception(str(e))
-    
+
     def taxi_invoice(self, form):
         try:
             res_json = self.common_handler("TaxiInvoice", form)
@@ -607,3 +648,17 @@ class VisualService(Service):
             return res_json
         except Exception as e:
             raise Exception(str(e))
+
+    def cert_token(self, form):
+        try:
+            res_json = self.common_json_handler("CertToken", form)
+            return res_json
+        except Exception as e:
+            raise Exception(str(e))
+
+    def cert_verify_query(self, form):
+        try:
+            res_json = self.common_json_handler("CertVerifyQuery", form)
+            return res_json
+        except Exception as e:
+            raise Exception(str(e))
